# Generated by Django 3.2.5 on 2022-11-08 13:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0002_alter_callbacks_reference'),
    ]

    operations = [
        migrations.CreateModel(
            name='RequestLogs',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip', models.CharField(max_length=50)),
                ('method', models.CharField(max_length=10)),
                ('path', models.CharField(max_length=100)),
                ('content_type', models.CharField(max_length=50)),
                ('content_params', models.JSONField(default=dict)),
                ('body', models.JSONField(default=dict)),
                ('headers', models.JSONField(default=dict)),
                ('user', models.CharField(max_length=100)),
            ],
        ),
    ]
